@@ -49,9 +49,7 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
         $this->assertSame('déjà', mb_convert_encoding(base64_encode('déjà'), 'Utf-8', 'Base64'));
         $this->assertSame('déjà', mb_convert_encoding('d&eacute;j&#224;', 'Utf-8', 'Html-entities'));
         $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', 'ASCII,ISO-2022-JP,UTF-8,ISO-8859-1'));
-        if (!defined('HHVM_VERSION')) {
-            $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', array('ASCII', 'ISO-2022-JP', 'UTF-8', 'ISO-8859-1')));
-        }
+        $this->assertSame('déjà', mb_convert_encoding(utf8_decode('déjà'), 'Utf-8', array('ASCII', 'ISO-2022-JP', 'UTF-8', 'ISO-8859-1')));
     }
 
     /**
@@ -66,6 +64,10 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
         if (PCRE_VERSION >= '8.10') {
             $this->assertSame('Déjà Σσσ Iı Ii İi', mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', MB_CASE_TITLE));
         }
+        if (PHP_VERSION_ID >= 70000) {
+            // Native iconv() is buggy before PHP 7
+            $this->assertSame('ab', str_replace('?', '', mb_strtolower(urldecode('a%A1%C0b'))));
+        }
     }
 
     /**
@@ -73,6 +75,8 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
      */
     public function testStrlen()
     {
+        $this->assertSame(2, mb_strlen("\x00\xFF", 'ASCII'));
+        $this->assertSame(2, mb_strlen("\x00\xFF", 'CP850'));
         $this->assertSame(3, mb_strlen('한국어'));
         $this->assertSame(8, mb_strlen(\Normalizer::normalize('한국어', \Normalizer::NFD)));
     }
@@ -93,6 +97,13 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
         $this->assertSame('',   mb_substr($c, -2, -2));
         $this->assertSame('',   mb_substr($c,  5,  0));
         $this->assertSame('',   mb_substr($c, -5,  0));
+
+        $this->assertSame("\xFF",     mb_substr("\x00\xFF", -1, 1, 'ASCII'));
+        $this->assertSame("\x00",     mb_substr("\x00\xFF", 0, 1, 'ASCII'));
+        $this->assertSame("\x00\xFF", mb_substr("\x00\xFF", 0, 2, 'ASCII'));
+        $this->assertSame("\xFF",     mb_substr("\x00\xFF", -1, 1, 'CP850'));
+        $this->assertSame("\x00",     mb_substr("\x00\xFF", 0, 1, 'CP850'));
+        $this->assertSame("\x00\xFF", mb_substr("\x00\xFF", 0, 2, 'CP850'));
     }
 
     /**
@@ -133,8 +144,12 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
     public function testStrposNegativeOffset()
     {
         mb_strpos('abc', 'a');
-        $this->setExpectedException('PHPUnit_Framework_Error_Warning', 'Offset not contained in string');
-        mb_strpos('abc', 'a', -1);
+        if (PHP_VERSION_ID >= 70100) {
+            $this->assertFalse(mb_strpos('abc', 'a', -1));
+        } else {
+            $this->setExpectedException('PHPUnit_Framework_Error_Warning', 'Offset not contained in string');
+            mb_strpos('abc', 'a', -1);
+        }
     }
 
     /**
@@ -224,4 +239,30 @@ class MbstringTest extends \PHPUnit_Framework_TestCase
         $this->assertSame(4, mb_strwidth('déjà', 'UTF-8'));
         $this->assertSame(4, mb_strwidth(utf8_decode('déjà'), 'CP1252'));
     }
+
+    /**
+     * @covers Symfony\Polyfill\Mbstring\Mbstring::mb_chr
+     */
+    public function testChr()
+    {
+        $this->assertSame("\xF0\xA0\xAE\xB7", mb_chr(0x20BB7));
+        $this->assertSame("\xE9", mb_chr(0xE9, 'CP1252'));
+    }
+
+    /**
+     * @covers Symfony\Polyfill\Mbstring\Mbstring::mb_ord
+     */
+    public function testOrd()
+    {
+        $this->assertSame(0x20BB7, mb_ord("\xF0\xA0\xAE\xB7"));
+        $this->assertSame(0xE9, mb_ord("\xE9", 'CP1252'));
+    }
+
+    public function testScrub()
+    {
+        $subst = \mb_substitute_character();
+        \mb_substitute_character('none');
+        $this->assertSame('ab', mb_scrub("a\xE9b"));
+        \mb_substitute_character($subst);
+    }
 }
