@@ -13,6 +13,12 @@ namespace Symfony\Polyfill\Tests\Php70;
 
 class Php70Test extends \PHPUnit_Framework_TestCase
 {
+    public function testPhpIntMin()
+    {
+        $this->assertTrue(defined('PHP_INT_MIN'));
+        $this->assertSame(~PHP_INT_MAX, PHP_INT_MIN);
+    }
+
     /**
      * @dataProvider provideIntdiv
      */
@@ -34,7 +40,7 @@ class Php70Test extends \PHPUnit_Framework_TestCase
     }
 
     /**
-     * @expectedException ArithmeticError
+     * @expectedException \ArithmeticError
      */
     public function testIntdivArithmetic()
     {
@@ -42,7 +48,7 @@ class Php70Test extends \PHPUnit_Framework_TestCase
     }
 
     /**
-     * @expectedException DivisionByZeroError
+     * @expectedException \DivisionByZeroError
      */
     public function testIntdivByZero()
     {
